@@ -9,8 +9,8 @@
 #' be particule counts, surfaces, volumes, etc.
 #' @param params A matrix with the following colums: CmTop, CmBot, AgeTop,
 #' AgeBot, Volume, in the same order.
-#' @param Int Logical specifying whether the function interpolates particle
-#' zero counts, default TRUE
+#' @param Int Logical specifying whether the function interpolates missing values, 
+#' default TRUE (missing values specified could be specified as -999 or NA)
 #' @param first,last Date of the first, last sample for accumulation rate
 #' calculation, if NULL first, last are automatically specified as the the
 #' minimum and maximum ages of the record respectively
@@ -63,7 +63,7 @@ pretreatment=function(params,serie,Int=TRUE,first=NULL,last=NULL,yrInterp=NULL){
   ## Interpolate or not zero counts
   if (Int==TRUE){
     ## SCREEEN RECORD FOR MISSING VALUES:
-    missingValuesIndex = which(count<=0)
+    missingValuesIndex = which(count<0 | is.na(count) | vol==0)
     nMissingValues = length(missingValuesIndex)
     if (nMissingValues > 0){  # if some levels were not sampled...
       startIn = missingValuesIndex[which(c(99, diff(missingValuesIndex)) > 1)] # Index start of gaps
@@ -220,6 +220,10 @@ pretreatment=function(params,serie,Int=TRUE,first=NULL,last=NULL,yrInterp=NULL){
 #' @method plot CHAR
 #' @export
 #' @param x An object of the class "CHAR".
+#' @param xlim xlim...
+#' @param ylim ylim...
+#' @param xlab x axis label.
+#' @param ylab y axis label.
 #' @param \dots \dots{}
 #' @author O. Blarquez
 #' @examples
@@ -236,7 +240,7 @@ pretreatment=function(params,serie,Int=TRUE,first=NULL,last=NULL,yrInterp=NULL){
 #' plot(CHAR)
 #' 
 #' 
-plot.CHAR=function(x,...){
+plot.CHAR=function(x, xlim=NULL, ylim=NULL,xlab=NULL,ylab=NULL,...){
   
   ## PLOT
   # Values for plotting
@@ -244,10 +248,13 @@ plot.CHAR=function(x,...){
   accInit<-rep(x$acc,each=2)
   ageInt=c(matrix(c(x$ybpI,x$ybpI+x$yrInterp), 2, byrow = TRUE)) 
   accInt<-rep(x$accI,each=2)
+  if(is.null(ylim)) ylim=c(min(na.omit(accInit)),max(na.omit(accInit)))
+  if(is.null(xlim)) xlim=c(max(age),min(age))
   
   # plot
-  plot(age,accInit,type="l",col="grey",ylim=c(min(na.omit(accInit)),max(na.omit(accInit))))
-  polygon(c(age,age[length(age)]), c(accInit,-100), col='grey') 
+  plot(age,accInit,type="l",col="grey",ylim=ylim,xlim=xlim,yaxs="i",
+       xlab=xlab,ylab=ylab)
+  polygon(c(age,age[length(age)]), c(accInit,-1e6), col='grey') 
   lines(age,accInit,type="l",col="grey")
   lines(ageInt,accInt,type="l")
 }
